@@ -1,6 +1,6 @@
-import autocomplete_light.shortcuts as autocomplete_light
+from dal import autocomplete
 from django.conf.urls.static import static
-autocomplete_light.autodiscover()
+#autocomplete.autodiscover()
 
 #from django.conf.urls import  include, url
 from django.urls import include, path,re_path
@@ -12,7 +12,7 @@ urlpatterns = [
     path('', include('django_microsip_base.apps.main.urls')),
     path('', include('microsip_api.apps.config.urls')),
     path('administrador/', include('microsip_api.apps.administrador.urls')),
-    path('autocomplete/', include('autocomplete_light.urls')),
+    #path('autocomplete/', include('autocomplete.urls')),
     path("select2/", include("django_select2.urls")),
     # path('media/<string:path>', include('django.views.static.serve'),
     #     {'document_root': settings.MEDIA_ROOT, }),
